==> aws-cdk-scala_3-0.19.0-sources.jar: io/burkard/cdk/services/stepfunctions/CfnStateMachine.scala <==
package io.burkard.cdk.services.stepfunctions

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnStateMachine {

  def apply(
    internalResourceId: String,
    roleArn: String,
    definitionString: Option[String] = None,
    definitionSubstitutions: Option[Map[String, String]] = None,
    loggingConfiguration: Option[software.amazon.awscdk.services.stepfunctions.CfnStateMachine.LoggingConfigurationProperty] = None,
    definitionS3Location: Option[software.amazon.awscdk.services.stepfunctions.CfnStateMachine.S3LocationProperty] = None,
    tags: Option[List[_ <: software.amazon.awscdk.services.stepfunctions.CfnStateMachine.TagsEntryProperty]] = None,
    stateMachineType: Option[String] = None,
    tracingConfiguration: Option[software.amazon.awscdk.services.stepfunctions.CfnStateMachine.TracingConfigurationProperty] = None,
    definition: Option[AnyRef] = None,
    stateMachineName: Option[String] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.stepfunctions.CfnStateMachine =
    software.amazon.awscdk.services.stepfunctions.CfnStateMachine.Builder
      .create(stackCtx, internalResourceId)
      .roleArn(roleArn)
      .definitionString(definitionString.orNull)
      .definitionSubstitutions(definitionSubstitutions.map(_.asJava).orNull)
      .loggingConfiguration(loggingConfiguration.orNull)
      .definitionS3Location(definitionS3Location.orNull)
      .tags(tags.map(_.asJava).orNull)
      .stateMachineType(stateMachineType.orNull)
      .tracingConfiguration(tracingConfiguration.orNull)
      .definition(definition.orNull)
      .stateMachineName(stateMachineName.orNull)
      .build()
}

==> aws-cdk-scala_3-0.22.0-sources.jar: io/burkard/cdk/services/stepfunctions/CfnStateMachine.scala <==
package io.burkard.cdk.services.stepfunctions

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnStateMachine {

  def apply(
    internalResourceId: String,
    roleArn: String,
    definitionString: Option[String] = None,
    definitionSubstitutions: Option[Map[String, _]] = None,
    loggingConfiguration: Option[software.amazon.awscdk.services.stepfunctions.CfnStateMachine.LoggingConfigurationProperty] = None,
    definitionS3Location: Option[software.amazon.awscdk.services.stepfunctions.CfnStateMachine.S3LocationProperty] = None,
    tags: Option[List[_ <: software.amazon.awscdk.services.stepfunctions.CfnStateMachine.TagsEntryProperty]] = None,
    stateMachineType: Option[String] = None,
    tracingConfiguration: Option[software.amazon.awscdk.services.stepfunctions.CfnStateMachine.TracingConfigurationProperty] = None,
    definition: Option[AnyRef] = None,
    stateMachineName: Option[String] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.stepfunctions.CfnStateMachine =
    software.amazon.awscdk.services.stepfunctions.CfnStateMachine.Builder
      .create(stackCtx, internalResourceId)
      .roleArn(roleArn)
      .definitionString(definitionString.orNull)
      .definitionSubstitutions(definitionSubstitutions.map(_.asJava).orNull)
      .loggingConfiguration(loggingConfiguration.orNull)
      .definitionS3Location(definitionS3Location.orNull)
      .tags(tags.map(_.asJava).orNull)
      .stateMachineType(stateMachineType.orNull)
      .tracingConfiguration(tracingConfiguration.orNull)
      .definition(definition.orNull)
      .stateMachineName(stateMachineName.orNull)
      .build()
}
